/**
 * Copyright (C) 2010-2012 enStratus Networks Inc
 *
 * ====================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ====================================================================
 */

package org.dasein.cloud.jclouds.atmos;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Locale;

import org.dasein.cloud.CloudException;
import org.dasein.cloud.InternalException;
import org.dasein.cloud.dc.DataCenter;
import org.dasein.cloud.dc.DataCenterServices;
import org.dasein.cloud.dc.Region;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

public class DataCenters implements DataCenterServices {
    private Atmos provider;
    
    DataCenters(@Nonnull Atmos atmos) { provider = atmos; }
    
    @Override
    public @Nullable DataCenter getDataCenter(@Nonnull String dataCenterId) throws InternalException, CloudException {
        if( provider.isATT() ) {
            if( dataCenterId.equals("us1") ) {
                DataCenter dc = new DataCenter();

                dc.setActive(true);
                dc.setAvailable(true);
                dc.setName("US 1");
                dc.setProviderDataCenterId("us1");
                dc.setRegionId("us");
                return dc;
            }
        }
        else {
            if( dataCenterId.equals("dc1") ) {
                DataCenter dc = new DataCenter();

                dc.setActive(true);
                dc.setAvailable(true);
                dc.setName("DC 1");
                dc.setProviderDataCenterId("dc1");
                dc.setRegionId("r1");
                return dc;
            }
        }
        return null;
    }

    @Override
    public @Nonnull String getProviderTermForDataCenter(@Nonnull Locale locale) {
        return "data center";
    }

    @Override
    public @Nonnull String getProviderTermForRegion(@Nonnull Locale locale) {
        return "region";
    }

    @Override
    public @Nullable Region getRegion(@Nonnull String regionId) throws InternalException, CloudException {
        for( Region r : listRegions() ) {
            if( regionId.equals(r.getProviderRegionId()) ) {
                return r;
            }
        }
        return null;
    }

    @Override
    public @Nonnull Collection<DataCenter> listDataCenters(@Nonnull String regionId) throws InternalException, CloudException {
        Region region = getRegion(regionId);
        
        if( region == null ) {
            throw new CloudException("No such region: " + regionId);
        }
        ArrayList<DataCenter> dataCenters= new ArrayList<DataCenter>();

        if( regionId.equals("us") ) {
            DataCenter dc = new DataCenter();
            
            dc.setActive(true);
            dc.setAvailable(true);
            dc.setName("US 1");
            dc.setProviderDataCenterId("us1");
            dc.setRegionId("us");
            dataCenters.add(dc);
        }
        else if( regionId.equals("r1") ) {
            DataCenter dc = new DataCenter();

            dc.setActive(true);
            dc.setAvailable(true);
            dc.setName("Region 1/DC 1");
            dc.setProviderDataCenterId("dc1");
            dc.setRegionId("r1");
            dataCenters.add(dc);            
        }
        return dataCenters;
    }

    @Override
    public @Nonnull Collection<Region> listRegions() throws InternalException, CloudException {
        ArrayList<Region> regions = new ArrayList<Region>();
        Region region = new Region();
        
        if( provider.isATT() ) {
            region.setActive(true);
            region.setAvailable(true);
            region.setName("US 1");
            region.setProviderRegionId("us");
            regions.add(region);
        }
        else {
            region.setActive(true);
            region.setAvailable(true);
            region.setName("Region 1");
            region.setProviderRegionId("r1");
            regions.add(region);            
        }
        return regions;
    }

}
